
#ifdef _WIN32
__declspec(dllexport)
#endif
  int empty_c(void)
{
  return 0;
}
